@@ -4,6 +4,7 @@ __license__ = "MPL 2.0"
 
 from subprocess import Popen, PIPE, STDOUT
 import json
+import yaml
 
 
 def read_json(filename):
@@ -12,6 +13,16 @@ def read_json(filename):
     return data
 
 
+def read_yaml(filepath):
+    with open(filepath, "r") as fd:
+        data = yaml.load(fd.read(), Loader=yaml.SafeLoader)
+    return data
+
+
+def row(cols):
+    return "|" + "|".join(cols) + "|\n"
+
+
 def run_command(cmd, sudo=False, stream=False):
     """run_command uses subprocess to send a command to the terminal.
 
