@@ -2,7 +2,7 @@ __author__ = "Vanessa Sochat"
 __copyright__ = "Copyright 2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
-__version__ = "0.0.12"
+__version__ = "0.0.14"
 AUTHOR = "Vanessa Sochat"
 AUTHOR_EMAIL = "vsoch@users.noreply.github.com"
 NAME = "compspec"
@@ -14,7 +14,10 @@ LICENSE = "LICENSE"
 ################################################################################
 # Global requirements
 
-INSTALL_REQUIRES = (("clingo", {"min_version": None}),)
+INSTALL_REQUIRES = (
+    ("clingo", {"min_version": None}),
+    ("pyaml", {"min_version": None}),
+)
 
 TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
 INSTALL_REQUIRES_ALL = INSTALL_REQUIRES + TESTS_REQUIRES
